// sitar_com.h
// $Id: sitar_com.h,v 1.1.1.1 2007/09/19 05:49:54 sendan Exp $
// masashi shimakura


#ifndef _SITAR_COM_H_
  #define _SITAR_COM_H_
  #ifndef COM_LEN
    #define COM_LEN 128
  #endif

  /* POPEN DEBUG */
//  #define POPEN_DEBUG
//  #define POPEN_FD_DEBUG

  /* PEXEC DEBUG  */
//  #define PEXEC_DEBUG
//  #define PEXEC_MUTEX_DEBUG

//  int * pids[COM_LEN];
//  int pids_count[COM_LEN];
//  int pids_count2[COM_LEN];

  /* -- p_exec.c -- */
  char * execom(char *, char *, int, int);
  char * out_execom(char *, char *, int, int);

  /* -- p_open.c BSD2.11 -- */
  int p_pclose(FILE *, int, int);
  FILE * p_popen(FILE *, char *, register char *, int *, int *, int, int);
//  int out_p_pclose(FILE *, int);
//  FILE * out_p_popen(FILE *, char *, register char *, int *, int *, int, int);

#endif

